@@ -33,7 +33,8 @@ def trace(zone):
 
 @decorator
 def adaptor(func, flow_id=None, *args, **kwargs):
-    os.environ["FLOW_ID"] = flow_id
+    test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
+    os.environ[f"FLOW_ID_{test_name}"] = flow_id
     return func(*args, **kwargs)
 
 
@@ -51,8 +52,9 @@ def logged_request(method, url, **kwargs):
         request = None
         response = None
         start_time = int(time.time() * 1000)
-        zone = os.environ.get("ZONE", None)
-        flow_id = os.environ.get("FLOW_ID", None)
+        test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
+        zone = os.environ.get(f"ZONE_{test_name}", None)
+        flow_id = os.environ.get(f"FLOW_ID_{test_name}", None)
 
         try:
             header_dict: dict = kwargs.get('headers', None)
@@ -61,7 +63,8 @@ def logged_request(method, url, **kwargs):
                 raise TypeError(
                     "Current probe has not been associated with a zone. Available zones can be obtained from : https://owcc-ssc.internal.olympus-world.zetaapps.in/zones/names")
 
-            if header_dict is not None and "nonpcidss" in zone:
+            # Hack for not generating token for PCI Zone for now
+            if header_dict is not None and "-pcidss-" not in zone:
                 header_dict.update(trace(zone))
             response = original_request_method(method, url, **kwargs)
             request = response.request
@@ -90,17 +93,17 @@ def sanitize_data(data: dict):
 def adapter_data(*, start_time, end_time, request=None, response=None, method=None, url=None, flow_id=None, zone=None):
     if request is not None:
         trace_id = request.headers.get("X-Olympus-Traceid", None)
+        test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
 
         if flow_id is not None and zone is not None:
-            del os.environ["FLOW_ID"]
-            del os.environ["ZONE"]
+            del os.environ[f"FLOW_ID_{test_name}"]
+            del os.environ[f"ZONE_{test_name}"]
 
             if response.status_code >= 500:
                 flag = 3
             else:
                 flag = 1
 
-            test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
             flow_probe_payload = test_name[test_name.find("[") + 1:test_name.find("]")]
             invocation_parameters = {
                 "markers": test_name.replace("[" + flow_probe_payload + "]", "").replace("test_", "").replace("tests_", "").lower()
